==> jc-1.4.0.tar.gz: gnu/xml/pipeline/ValidationConsumer__24MixedRecognizer.h <==
// final class gnu.xml.pipeline.ValidationConsumer$MixedRecognizer

// class file dependencies
// @dep_class 74fccadfaa23c924 gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer
// @dep_class c3c82d7a3ea2ae0e gnu_xml_pipeline_ValidationConsumer__24Recognizer
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_pipeline_ValidationConsumer__24Recognizer

#include "gnu/xml/pipeline/ValidationConsumer__24Recognizer.h"

#ifndef _JC_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer_H_
#define _JC_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer_H_

// Forward structure declarations
struct _jc_gnu_xml_pipeline_ValidationConsumer$object;
struct _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$object;
struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$sub_refs	_jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$sub_refs;
typedef struct _jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$sub_nonrefs	_jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$sub_nonrefs;
typedef struct _jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$refs	_jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$refs;
typedef struct _jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$nonrefs	_jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$nonrefs;
typedef struct _jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$object	_jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$object;

typedef const struct _jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$vmethods	_jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$vmethods;
typedef const struct _jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$vtable	_jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$vtable;
typedef const struct _jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$vtype	_jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$vtype;

// Constructors
extern void _jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$method$_init$93be39ccf36460f7(_jc_env *, struct _jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$object *, struct _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$object *, struct _jc_gnu_xml_pipeline_ValidationConsumer$object *);

// Virtual methods
extern struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$object *_jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$method$acceptElement$99cdc60944f2d23c(_jc_env *, struct _jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$method_info$acceptElement$99cdc60944f2d23c;

// Virtual methods structure
struct _jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$vmethods {
	struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$object	*(*acceptElement$99cdc60944f2d23c)(_jc_env *, struct _jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$vmethods	gnu_xml_pipeline_ValidationConsumer__24Recognizer;
	_jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$vmethods	gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer;
};

// Vtype
struct _jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$vtype {
	_jc_type			type;
	_jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$sub_refs {
	_jc_object_array	*permitted;
};

// Reference instance fields (object)
struct _jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$refs {
    _jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$sub_refs	gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer;
    _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$sub_refs	gnu_xml_pipeline_ValidationConsumer__24Recognizer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$sub_nonrefs	gnu_xml_pipeline_ValidationConsumer__24Recognizer;
    _jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$sub_nonrefs	gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer;
};

// Object instance structure
struct _jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$object {
	_jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$vtype	*vtype;
	_jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$vtype _jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$class_object;

#endif	/* _JC_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/pipeline/ValidationConsumer__24MixedRecognizer.h <==
// final class gnu.xml.pipeline.ValidationConsumer$MixedRecognizer

// class file dependencies
// @dep_class 74fccadfaa23c924 gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer
// @dep_class c3c82d7a3ea2ae0e gnu_xml_pipeline_ValidationConsumer__24Recognizer
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_pipeline_ValidationConsumer__24Recognizer

#include "gnu/xml/pipeline/ValidationConsumer__24Recognizer.h"

#ifndef _JC_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer_H_
#define _JC_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer_H_

// Forward structure declarations
struct _jc_gnu_xml_pipeline_ValidationConsumer$object;
struct _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$object;
struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$sub_refs	_jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$sub_refs;
typedef struct _jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$sub_nonrefs	_jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$sub_nonrefs;
typedef struct _jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$refs	_jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$refs;
typedef struct _jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$nonrefs	_jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$nonrefs;
typedef struct _jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$object	_jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$object;

typedef const struct _jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$vmethods	_jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$vmethods;
typedef const struct _jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$vtable	_jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$vtable;
typedef const struct _jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$vtype	_jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$vtype;

// Constructors
extern void _jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$method$_init$93be39ccf36460f7(_jc_env *, struct _jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$object *, struct _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$object *, struct _jc_gnu_xml_pipeline_ValidationConsumer$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$object *_jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$method$acceptElement$99cdc60944f2d23c(_jc_env *, struct _jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$method_info$acceptElement$99cdc60944f2d23c;

// Virtual methods structure
struct _jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$vmethods {
	struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$object	*(*acceptElement$99cdc60944f2d23c)(_jc_env *, struct _jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$vmethods	gnu_xml_pipeline_ValidationConsumer__24Recognizer;
	_jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$vmethods	gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer;
};

// Vtype
struct _jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$vtype {
	_jc_type			type;
	_jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$sub_refs {
	_jc_object_array	*permitted;
};

// Reference instance fields (object)
struct _jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$refs {
    _jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$sub_refs	gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer;
    _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$sub_refs	gnu_xml_pipeline_ValidationConsumer__24Recognizer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$sub_nonrefs	gnu_xml_pipeline_ValidationConsumer__24Recognizer;
    _jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$sub_nonrefs	gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer;
};

// Object instance structure
struct _jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$object {
	_jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$vtype	*vtype;
	_jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$vtype _jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer$class_object;

#endif	/* _JC_gnu_xml_pipeline_ValidationConsumer__24MixedRecognizer_H_ */
